/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.column;

import org.opengion.hayabusa.db.AbstractRenderer;
import org.opengion.hayabusa.db.CellRenderer;
import org.opengion.hayabusa.db.DBColumn;

/**
 * YMD レンデラーは、カラムのデータを日付(年/月/日)表示する場合に使用するクラスです。
 * 9999年のデータは""(0ストリング)で返します。
 *
 * このクラスは、不変オブジェクトとして、共有されます。
 *
 * @og.group データ表示
 *
 * @version  4.0
 * @author   Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public class Renderer_YMD31 extends AbstractRenderer {
	//* このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "5.5.7.2 (2012/10/09)" ;

	private static final CellRenderer dbCell = new Renderer_YMD31() ;

	/**
	 * 各オブジェクトから自分のインスタンスを返します。
	 * 自分自身をキャッシュするのか、新たに作成するのかは、各サブクラスの実装に
	 * まかされます。
	 *
	 * @og.rev 3.1.1.1 (2003/04/03) 各オブジェクトから自分のインスタンスを返すファクトリメソッドを追加。
	 * @og.rev 3.1.2.1 (2003/04/10) synchronized を、削除します。
	 *
	 * @param	clm DBColumnオブジェクト
	 *
	 * @return	CellRendererオブジェクト
	 */
	public CellRenderer newInstance( final DBColumn clm ) {
		return dbCell;
	}

	/**
	 * データの表示用文字列を返します。
	 * ここでは、null か ゼロ文字列の場合は、ゼロ文字列を返します。
	 * ８ケタ以下のデータは、エラー表示を行います。
	 * ８ケタ以上の場合は、YYYYMMDDxxxxxx として、YYYY/MM/DD を返します。
	 * このクラスは、先頭が 9999 の場合は、空文字列を返します。
	 *
	 * @og.rev 3.8.1.1 (2005/11/21) フォーマットエラー時には、class="error" を付けて表示させる。
	 * @og.rev 5.5.7.2 (2012/10/09) 処理ロジックの見直し
	 *
	 * @param   value 入力値
	 *
	 * @return  データの表示用文字列
	 */
	@Override
	public String getValue( final String value ) {
		if( value == null || value.length() == 0 || value.startsWith( "9999" ) ) { return ""; }

		String rtn = value;

		if( rtn.length() >= 8 ) {
			char[] ch1 = new char[10];
			ch1[0] = rtn.charAt(0);
			ch1[1] = rtn.charAt(1);
			ch1[2] = rtn.charAt(2);
			ch1[3] = rtn.charAt(3);
			ch1[4] = '/' ;
			ch1[5] = rtn.charAt(4);
			ch1[6] = rtn.charAt(5);
			ch1[7] = '/' ;
			ch1[8] = rtn.charAt(6);
			ch1[9] = rtn.charAt(7);

			rtn = new String( ch1 );
		}
		else {
			rtn = "<span class=\"error\">" + value + "</span>";
		}
		return rtn;

//		final String rtn;
//		if( value == null || value.length() == 0 || value.startsWith( "9999" ) ) {
//			rtn = "";
//		}
//		else if( value.length() >= 8 ) {
//			StringBuilder buf = new StringBuilder( value );
//			buf.insert( 6,'/' );
//			buf.insert( 4,'/' );
//			rtn = buf.toString();
//		}
//		else {
//			rtn = "<span class=\"error\">" + value + "</span>";
//		}
//		return rtn;
	}
}
